#ifndef ADABINDING_H_
#define ADABINDING_H_

#include <string>
#include <qpid/client/Connection.h>
#include <qpid/client/Session.h>
#include <qpid/client/AsyncSession.h>
#include <qpid/client/SubscriptionManager.h>
#include <qpid/client/Message.h>
#include <qpid/sys/Time.h>

using namespace std;
using namespace qpid::client;
using namespace qpid::framing;
using namespace qpid::sys;


class MessageC{
  public:
  	int priority;
	const char* routingKey;
	int expirationTime;
	const char* deliveryMode;
	const char* contentType;
	const char* contentEncoding;
	const char* content;
	void SetMessage(int p, const char* rK, const int eT, const char* dM, const char* cT, const char* cE, const char* c);
	const char* GetContent();
	MessageC(void);
};

class SessionC {
 public:
    SessionC(void);
    void MessageTransfer(const char* destination, MessageC & msg);
    void Bind(const char* queueName, const char* exchangeName, const char* bindingKey);
    void ExchangeDeclare(const char* exchangeName, const char* exchangeType, const char* alternateExchange,
    					bool durable, bool autoDelete);
   	void ExchangeDelete(const char* exchangeName, bool if_Unused);
    void Unbind(const char* queueName, const char* exchangeName, const char* routingKey);
    void QueueDeclare(const char* queueName, const char* alternateExchange, bool durable, bool exclusive, bool autoDelete);
    void QueueDelete(const char* queueName, bool if_Unused);
    void Purge(const char* queueName);
   	Session session; 		
};

class LocalQueueC{
  public:
  	LocalQueueC(void);
  	~LocalQueueC(void);
  	MessageC Get(int timeOut);
  	void GetNoSub(char*,SessionC,  MessageC &, int);
  	bool Empty() const;
  	int Size() const;
  	LocalQueue* localQueue;
};

class ConnectionC {
 public:
    void Open(const char* host, int port, const char* uid, const char* pwd);
    void Close();
    void StartSession(SessionC Ses) const;
    ConnectionC(void);
    ~ConnectionC(void);
 private:
 	Connection* connection;	
};

#endif /*ADABINDING_H_*/
